
Why joblib: project goals
=========================

Joblibspark's approach
-----------------

This library provides Apache Spark backend for joblib to distribute tasks on a Spark cluster.

Design choices
--------------

* Make joblib task running on spark workers

* Robust, well-tested code, at the cost of functionality

* Fast and suitable for scientific computing on big dataset without
  changing the original code




